Hall of Fame
============
Albumentations are widely used in Computer Vision Competitions at Kaggle an other platforms.

Here are the links to the competitions, names of the winners and to their solutions.

We follow these rules, when adding a solution to the "Hall of Fame":

1. There should be a description of the solution: post at the forum / code / blog post / paper / pre-print.

2. Solution should have some value:

* For Kaggle: gold or silver medal solutions.
* For Topcoder and other platforms: in money.
* For competitions held as a part of the academic conferences: there is a paper or pre-print describing the solution.


Kaggle
------

`Carvana Image Masking Challenge <https://www.kaggle.com/c/carvana-image-masking-challenge>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. `Vladimir Iglovikov <https://www.linkedin.com/in/iglovikov/>`__, `Alexander Buslaev <https://www.kaggle.com/albuslaev>`__, `Artem Sanakoev <https://www.kaggle.com/asanakoev>`__
    `solution <http://blog.kaggle.com/2017/12/22/carvana-image-masking-first-place-interview/>`_

`Data Science Bowl 2018 <https://www.kaggle.com/c/data-science-bowl-2018>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. `Alexander Buslaev <https://www.kaggle.com/albuslaev>`__, `Selim Seferbekov <https://www.kaggle.com/selimsef>`__, `Victor Durnov <https://www.kaggle.com/victorsd>`__
    `solution <https://www.kaggle.com/c/data-science-bowl-2018/discussion/5474>`__

`Humpback Whale Identification <https://www.kaggle.com/c/humpback-whale-identification>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
5. `Roman Solovyev <https://www.kaggle.com/zfturbo>`__, `Weimin Wang <https://www.kaggle.com/weimin>`__
    `blog post <https://weiminwang.blog/2019/03/01/whale-identification-5th-place-approach-using-siamese-networks-with-adversarial-training/>`__,
    `code <https://github.com/aaxwaz/Humpback-whale-identification-challenge>`__

`TGS Salt Identification Challenge <https://www.kaggle.com/c/tgs-salt-identification-challeng>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. `b.e.s. <https://www.kaggle.com/ybabakhin>`__, `phalanx <https://www.kaggle.com/phalanx>`__
    `solution <https://www.kaggle.com/c/tgs-salt-identification-challenge/discussion/69291>`__,
    `code <https://github.com/ybabakhin/kaggle_salt_bes_phalanx>`__,
    `pre-print <https://arxiv.org/abs/1904.04445>`__

27. `Insaf Ashrapov <https://www.linkedin.com/in/iashrapov/>`__, `Mikhail Karchevskiy <https://www.linkedin.com/in/mikhail-karchevskiy-aa46245a/>`__, `Leonid Kozinkin <https://www.linkedin.com/in/lkozinkin/>`__
     `blog post <https://towardsdatascience.com/kaggle-salt-identification-challenge-7fc502d1c3c3>`__,
     `code <https://github.com/K-Mike/Automatic-salt-deposits-segmentation>`__,
     `pre-print <https://arxiv.org/abs/1812.01429>`__

`APTOS 2019 Blindness Detection <https://www.kaggle.com/c/aptos2019-blindness-detection>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
7. `Eugene Khvedchenya <https://www.kaggle.com/bloodaxe>`__
    `solution <https://www.kaggle.com/c/aptos2019-blindness-detection/discussion/108058>`__,
    `code <https://github.com/BloodAxe/Kaggle-2019-Cellular-Image-Classification>`__

76. `Insaf Ashrapov <https://www.linkedin.com/in/iashrapov/>`__, `Mamat Shamshiev <https://www.kaggle.com/mamatml/>`__, `Mishunyayev Nikita <https://www.kaggle.com/mnikita/>`__
     `solution <https://www.kaggle.com/c/aptos2019-blindness-detection/discussion/108057>`__,
     `code <https://github.com/MamatShamshiev/Kaggle-APTOS-2019-Blindness-Detection>`__

`SIIM-ACR Pneumothorax Segmentation <https://www.kaggle.com/c/siim-acr-pneumothorax-segmentation>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. `Anuar Aimoldin <https://www.linkedin.com/in/anuar-aimoldin/>`__
     `solution <https://www.kaggle.com/c/siim-acr-pneumothorax-segmentation/discussion/107824>`__,
     `code <https://github.com/sneddy/pneumothorax-segmentation>`__,
     `video <https://youtu.be/Wuf0wE3Mrxg>`__,
     `presentation <https://yadi.sk/i/oDYnpvMhqi8a7w>`__

4. `Miras Amir <https://www.linkedin.com/in/amirassov/>`__
     `solution <https://www.kaggle.com/c/siim-acr-pneumothorax-segmentation/discussion/108397#latest-626947>`__,
     `code <https://github.com/amirassov/kaggle-pneumothorax>`__

33. `Renat Alimbekov <https://www.linkedin.com/in/alimbekovkz/>`__, `Ivan Vassilenko <https://www.linkedin.com/in/ivannvassilenko/>`__
     `solution <https://github.com/jovenwayfarer/kaggle-pneumothorax>`__

50. `AlexeyK <https://www.kaggle.com/akuritsyn>`__, `wayfarer <https://www.kaggle.com/joven1997>`__, `Kudaibergen R <https://www.kaggle.com/kudaibergenu>`__
     `code and solution <https://github.com/jovenwayfarer/kaggle-pneumothorax>`__

`iMaterialist (Fashion) 2019 at FGVC6 <https://www.kaggle.com/c/imaterialist-fashion-2019-FGVC6>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. `Miras Amir <https://www.linkedin.com/in/amirassov/>`__
     `solution <https://www.kaggle.com/c/imaterialist-fashion-2019-FGVC6/discussion/95247#latest-626701>`__,
     `code <https://github.com/amirassov/kaggle-imaterialist>`__

`Google Landmark Recognition 2019 <https://www.kaggle.com/c/landmark-recognition-2019>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
20. `Artyom Palvelev <https://www.linkedin.com/in/artyompp/>`__
     `solution <https://www.kaggle.com/c/landmark-recognition-2019/discussion/94645#latest-549974>`__,
     `code <https://github.com/artyompal/google_landmark_2019>`__

`Inclusive Images Challenge <https://www.kaggle.com/c/inclusive-images-challenge/>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
3. `Roman Solovyev <https://www.kaggle.com/zfturbo>`_, `Weimin Wang <https://www.kaggle.com/weimin>`__
    `solution <https://www.kaggle.com/c/inclusive-images-challenge/discussion/71433>`__

`Airbus Ship Detection Challenge <https://www.kaggle.com/c/airbus-ship-detection/>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
30. `Konstantin Maksimov <https://www.kaggle.com/maksimovka>`__
     `paper <https://ieeexplore.ieee.org/document/8783822/authors#authors>`__

`Severstal: Steel Defect Detection Challenge <https://www.kaggle.com/c/severstal-steel-defect-detection/>`_
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
27. `Ilia Larchenko <https://www.kaggle.com/ilialar>`__
     `solution <https://www.kaggle.com/c/severstal-steel-defect-detection/discussion/115876>`_

Topcoder
--------
2019
^^^^
`Neptune - Facial Detection Marathon Match <https://www.topcoder.com/challenges/30086997>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
2. `Miras Amir <https://www.linkedin.com/in/amirassov/>`__
     `solution <https://github.com/amirassov/topcoder-facial-marathon>`__

`Neptune - Facial Re-Identification Marathon Match <https://www.topcoder.com/challenges/30086998>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
2. `Miras Amir <https://www.linkedin.com/in/amirassov/>`__
     `solution <https://github.com/amirassov/topcoder-facial-marathon>`__

2018
^^^^
`SpaceNet Challenge Round 4: Off-Nadir Buildings <https://spacenet.ai/off-nadir-building-detection/>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
3. `Konstantin Maksimov <https://www.linkedin.com/in/konstantin-maksimov/>`__
     `solution <https://github.com/SpaceNetChallenge/SpaceNet_Off_Nadir_Solutions/tree/master/MaksimovKA_solution>`__

CVPR
----
2018
^^^^

`DeepGlobe: Road Extraction <https://competitions.codalab.org/competitions/18467>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
2. `Vladimir Iglovikov <https://www.linkedin.com/in/iglovikov/>`__, `Alexander Buslaev <https://www.kaggle.com/albuslaev>`__, `Selim Seferbekov <https://www.kaggle.com/selimsef>`__, `Alexey Shvets <https://www.linkedin.com/in/shvetsiya/>`__
    `paper <http://openaccess.thecvf.com/content_cvpr_2018_workshops/papers/w4/Buslaev_Fully_Convolutional_Network_CVPR_2018_paper.pdf>`__

`Deepglobe: Building detection <https://competitions.codalab.org/competitions/18544>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
2. `Vladimir Iglovikov <https://www.linkedin.com/in/iglovikov/>`__, `Alexander Buslaev <https://www.kaggle.com/albuslaev>`__, `Selim Seferbekov <https://www.kaggle.com/selimsef>`__, `Alexey Shvets <https://www.linkedin.com/in/shvetsiya/>`__
    `paper <http://openaccess.thecvf.com/content_cvpr_2018_workshops/papers/w4/Iglovikov_TernausNetV2_Fully_Convolutional_CVPR_2018_paper.pdf>`__

`Deepglobe: Land Cover Classification <https://competitions.codalab.org/competitions/18468>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
3. `Vladimir Iglovikov <https://www.linkedin.com/in/iglovikov/>`__, `Alexander Buslaev <https://www.kaggle.com/albuslaev>`__, `Selim Seferbekov <https://www.kaggle.com/selimsef>`__, `Alexey Shvets <https://www.linkedin.com/in/shvetsiya/>`__
    `paper <http://openaccess.thecvf.com/content_cvpr_2018_workshops/papers/w4/Seferbekov_Feature_Pyramid_Network_CVPR_2018_paper.pdf>`__

MICCAI
------
2017
^^^^
`Robotic Instrument Segmentation <https://endovissub2017-roboticinstrumentsegmentation.grand-challenge.org/>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. `Vladimir Iglovikov <https://www.linkedin.com/in/iglovikov/>`__, `Alexey Shvets <https://www.linkedin.com/in/shvetsiya/>`__
    `paper <https://ieeexplore.ieee.org/abstract/document/8614125>`__,
    `pre-print from organizers <https://arxiv.org/abs/1902.06426>`__

`GIANA: Angiodysplasia localization <https://endovissub2017-giana.grand-challenge.org/Tasks/>`__
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
1. `Vladimir Iglovikov <https://www.linkedin.com/in/iglovikov/>`__, `Alexey Shvets <https://www.linkedin.com/in/shvetsiya/>`__
    `paper <https://ieeexplore.ieee.org/abstract/document/8614123>`__
